# Python Transformation Examples

## Overview

This folder contains example python scripts to be used inside a Pyodide web-based environment.

## Code block comments

The implementation in is using commentaries as below to separate the code blocks in the user interface. For example, the following code block comment:

```python
"""TITLE: Place a 2D material Layer on a Surface."""
```
will be rendered as the title of the file in the user interface, and the below comment:

```python
"""BLOCK: Install Dependencies"""
```
will be rendered as a title of the code block in the user interface.

## Links

1. Pyodide.org, official website: [link](https://pyodide.org/en/stable/).
